# WARP: Wrapper around Replicated Processes

Installation
`pip install warp`

Usage
```
from warp import Warp
from nucleonic import nucleonic_config
# set up your config
warp = Warp(nucleonic_config)
```


